@@ -60,6 +60,54 @@ func ConvertToRPCCustomResources(resources []ftypes.CustomResource) []*common.Cu
 	return rpcResources
 }
 
+func ConvertToRPCCode(code ftypes.Code) *common.Code {
+	var rpcLines []*common.Line
+	for _, line := range code.Lines {
+		rpcLines = append(rpcLines, &common.Line{
+			Number:      int32(line.Number),
+			Content:     line.Content,
+			IsCause:     line.IsCause,
+			Annotation:  line.Annotation,
+			Truncated:   line.Truncated,
+			Highlighted: line.Highlighted,
+			FirstCause:  line.FirstCause,
+			LastCause:   line.LastCause,
+		})
+	}
+	return &common.Code{
+		Lines: rpcLines,
+	}
+}
+
+func ConvertToRPCSecrets(secrets []ftypes.Secret) []*common.Secret {
+	var rpcSecrets []*common.Secret
+	for _, s := range secrets {
+		rpcSecrets = append(rpcSecrets, &common.Secret{
+			Filepath: s.FilePath,
+			Findings: ConvertToRPCSecretFindings(s.Findings),
+		})
+	}
+	return rpcSecrets
+}
+
+func ConvertToRPCSecretFindings(findings []ftypes.SecretFinding) []*common.SecretFinding {
+	var rpcFindings []*common.SecretFinding
+	for _, f := range findings {
+		rpcFindings = append(rpcFindings, &common.SecretFinding{
+			RuleId:    f.RuleID,
+			Category:  string(f.Category),
+			Severity:  f.Severity,
+			Title:     f.Title,
+			EndLine:   int32(f.EndLine),
+			StartLine: int32(f.StartLine),
+			Code:      ConvertToRPCCode(f.Code),
+			Match:     f.Match,
+			Layer:     ConvertToRPCLayer(f.Layer),
+		})
+	}
+	return rpcFindings
+}
+
 // ConvertFromRPCPkgs returns list of Fanal package objects
 func ConvertFromRPCPkgs(rpcPkgs []*common.Package) []ftypes.Package {
 	var pkgs []ftypes.Package
@@ -181,8 +229,9 @@ func ConvertToRPCMisconfs(misconfs []types.DetectedMisconfiguration) []*common.D
 // ConvertToRPCLayer returns common.Layer
 func ConvertToRPCLayer(layer ftypes.Layer) *common.Layer {
 	return &common.Layer{
-		Digest: layer.Digest,
-		DiffId: layer.DiffID,
+		Digest:    layer.Digest,
+		DiffId:    layer.DiffID,
+		CreatedBy: layer.CreatedBy,
 	}
 }
 
@@ -210,6 +259,7 @@ func ConvertFromRPCResults(rpcResults []*scanner.Result) []types.Result {
 			Type:              result.Type,
 			Packages:          ConvertFromRPCPkgs(result.Packages),
 			CustomResources:   ConvertFromRPCCustomResources(result.CustomResources),
+			Secrets:           ConvertFromRPCSecretFindings(result.Secrets),
 		})
 	}
 	return results
@@ -232,6 +282,58 @@ func ConvertFromRPCCustomResources(rpcCustomResources []*common.CustomResource)
 	return resources
 }
 
+func ConvertFromRPCCode(rpcCode *common.Code) ftypes.Code {
+	var lines []ftypes.Line
+	for _, line := range rpcCode.Lines {
+		lines = append(lines, ftypes.Line{
+			Number:      int(line.Number),
+			Content:     line.Content,
+			IsCause:     line.IsCause,
+			Annotation:  line.Annotation,
+			Truncated:   line.Truncated,
+			Highlighted: line.Highlighted,
+			FirstCause:  line.FirstCause,
+			LastCause:   line.LastCause,
+		})
+	}
+	return ftypes.Code{
+		Lines: lines,
+	}
+}
+
+func ConvertFromRPCSecretFindings(rpcFindings []*common.SecretFinding) []ftypes.SecretFinding {
+	var findings []ftypes.SecretFinding
+	for _, finding := range rpcFindings {
+		findings = append(findings, ftypes.SecretFinding{
+			RuleID:    finding.RuleId,
+			Category:  ftypes.SecretRuleCategory(finding.Category),
+			Severity:  finding.Severity,
+			Title:     finding.Title,
+			StartLine: int(finding.StartLine),
+			EndLine:   int(finding.EndLine),
+			Code:      ConvertFromRPCCode(finding.Code),
+			Match:     finding.Match,
+			Layer: ftypes.Layer{
+				Digest:    finding.Layer.Digest,
+				DiffID:    finding.Layer.DiffId,
+				CreatedBy: finding.Layer.CreatedBy,
+			},
+		})
+	}
+	return findings
+}
+
+func ConvertFromRPCSecrets(recSecrets []*common.Secret) []ftypes.Secret {
+	var secrets []ftypes.Secret
+	for _, secret := range recSecrets {
+		secrets = append(secrets, ftypes.Secret{
+			FilePath: secret.Filepath,
+			Findings: ConvertFromRPCSecretFindings(secret.Findings),
+		})
+	}
+	return secrets
+}
+
 // ConvertFromRPCVulns converts []*common.Vulnerability to []types.DetectedVulnerability
 func ConvertFromRPCVulns(rpcVulns []*common.Vulnerability) []types.DetectedVulnerability {
 	var vulns []types.DetectedVulnerability
@@ -446,6 +548,7 @@ func ConvertFromRPCPutBlobRequest(req *cache.PutBlobRequest) ftypes.BlobInfo {
 		OpaqueDirs:        req.BlobInfo.OpaqueDirs,
 		WhiteoutFiles:     req.BlobInfo.WhiteoutFiles,
 		CustomResources:   ConvertFromRPCCustomResources(req.BlobInfo.CustomResources),
+		Secrets:           ConvertFromRPCSecrets(req.BlobInfo.Secrets),
 	}
 }
 
@@ -556,6 +659,7 @@ func ConvertToRPCBlobInfo(diffID string, blobInfo ftypes.BlobInfo) *cache.PutBlo
 			OpaqueDirs:        blobInfo.OpaqueDirs,
 			WhiteoutFiles:     blobInfo.WhiteoutFiles,
 			CustomResources:   customResources,
+			Secrets:           ConvertToRPCSecrets(blobInfo.Secrets),
 		},
 	}
 }
@@ -596,6 +700,7 @@ func ConvertToRPCScanResponse(results types.Results, fos *ftypes.OS) *scanner.Sc
 			Misconfigurations: ConvertToRPCMisconfs(result.Misconfigurations),
 			Packages:          ConvertToRPCPkgs(result.Packages),
 			CustomResources:   ConvertToRPCCustomResources(result.CustomResources),
+			Secrets:           ConvertToRPCSecretFindings(result.Secrets),
 		})
 	}
 
